package il.ac.tau.cs.software1.ex5;

public interface IIPAddress {
	
	/**
	 * Returns a string representation of the IP address, for example "192.168.0.1"
	 */
	public String toString();
	
	/** 
	 * @param ip IP address to which we compare this address
	 * @return true if both objects represent the same address
	 */
	public boolean equals(IIPAddress ip);
	
	/**
	 * Returns one of the four parts of the IP address
	 * 
	 * @param index legal vales are [0..3], for example 192.168.0.1 would return 192 for index 0
	 * @return the desired part of the IP address (one of four parts) [0..255]
	 */
	public int getOctet(int index);
	
	/**
	 * There are four classes of private networks (http://en.wikipedia.org/wiki/IPv4#Private_networks)
	 * 		10.0.0.0 ? 10.255.255.255
	 * 		172.16.0.0 ? 172.31.255.255
	 * 		192.168.0.0 ? 192.168.255.255
	 * 		169.254.0.0 ? 169.254.255.255
	 * 
	 * This query returns true if this object is a private network address
	 */
	public boolean isPrivateNetwork();
	
	/**
	 * This command receives as a parameter an IP address and uses it to mask the current address
	 * i.e. perform a bitwise 'and' operator on all four parts
	 * 
	 * @param mask the IP address with which to mask
	 */
	public void mask(IIPAddress mask);	
}
